This folder contains [sim-and-plot.py](sim-and-plot.py), which runs
Modelica.Electrical.Analog.Examples.ChuaCircuit from the
[Modelica Standard Library] with various parameter settings and plots the
results.  The results of that script and some examples from the
[modelicares.exps](../../modelicares/exps) module are also generated here.


[Modelica Standard Library]: https://github.com/modelica/ModelicaStandardLibrary
